yakumo.cinder.v2.service.Resource

Package yakumo :: Package cinder :: Package v2 :: Module service :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for services in Block Storage API v2

Instance Methods | [hide private]
None |
enable(self) Enable a service on a host | source code
None |
disable(self) Disable a service on a host | source code
None |
set_disabled_reason(self, reason=None) Set disabled reason for a service on a host | source code
None |
update(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) Create a host aggregate | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### set_disabled_reason(self, reason=None) | source code
Set disabled reason for a service on a host Parameters: `reason` (str) - Description Returns: None

### update(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) | source code
Create a host aggregate Parameters: `name` (str) - name of the host aggregate `availability_zone` (str) - name of availability zone Returns: None Overrides: base.Resource.update